Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ActionAll = Action{"*", false} ActionAnySafe = Action{"any_safe", true} )
Functions ¶
This section is empty.
Types ¶
type Action ¶
func HTTPMethodAction ¶
type Conditions ¶
type Conditions []Condition
type Principal ¶
type Principal string
func GroupPrincipal ¶
GroupPrincipal will match any user that is in any of the groups
func PermissionPrincipal ¶
PermissionPrincipal will match any user that has all the permissions TODO: support OR ?
func UserPrincipal ¶
UserPrincipal will match any user whose ID is in the list
Click to show internal directories.
Click to hide internal directories.